@@ -43,7 +43,7 @@ class Community(EZPackOverlay):
         self._prefix = b'\x00' + self.version + self.community_id
         self.endpoint.remove_listener(self)
         self.endpoint.add_prefix_listener(self, self._prefix)
-        self.logger.debug("Launching %s with prefix %s.", self.__class__.__name__, hexlify(self._prefix))
+        self.logger.debug("Launching %s with prefix %s.", self.__class__.__name__, hexlify(self._prefix).decode())
 
         self.max_peers = max_peers
         self.anonymize = anonymize
@@ -112,6 +112,12 @@ class Community(EZPackOverlay):
     def get_prefix(self):
         return self._prefix
 
+    async def unload(self):
+        while self.bootstrappers:
+            bootstrapper = self.bootstrappers.pop()
+            bootstrapper.unload()
+        await super().unload()
+
     def add_message_handler(self, msg_num, callback):
         """
         Add a handler for a message identifier. Any messages coming in with this identifier will be delivered to
@@ -254,7 +260,7 @@ class Community(EZPackOverlay):
         if introduced:
             packet = self.create_puncture_request(lan_socket_address, socket_address, identifier, prefix=prefix,
                                                   new_style=new_style)
-            self.endpoint.send(introduction_wan if introduction_lan == ("0.0.0.0", 0) else introduction_lan, packet)
+            self.endpoint.send(introduction.address, packet)
 
         return self._ez_pack(prefix or self._prefix, payload.msg_id, [auth, dist, payload])
 
@@ -344,7 +350,7 @@ class Community(EZPackOverlay):
 
     def on_introduction_response(self, peer, dist, payload):
         if (isinstance(payload.destination_address, UDPv4Address)
-                and not self.address_is_lan(payload.destination_address[0])):
+                and not self.address_in_lan_subnets(payload.destination_address[0])):
             self.my_estimated_wan = payload.destination_address
         self.my_peer.address = payload.destination_address
 
