@@ -6,13 +6,14 @@ from .tunnel import CIRCUIT_STATE_CLOSING, CIRCUIT_STATE_READY
 from ...requestcache import NumberCache, RandomNumberCache
 
 
-class CreateRequestCache(NumberCache):
+class CreateRequestCache(RandomNumberCache):
     """
     Used to track outstanding create messages
     """
     def __init__(self, community, identifier, to_circuit_id, from_circuit_id, peer, to_peer):
-        super().__init__(community.request_cache, "create", identifier)
+        super().__init__(community.request_cache, "create")
         self.community = community
+        self.extend_identifier = identifier
         self.to_circuit_id = to_circuit_id
         self.from_circuit_id = from_circuit_id
         self.peer = peer
@@ -110,29 +111,30 @@ class RPRequestCache(RandomNumberCache):
 
 class PeersRequestCache(RandomNumberCache):
 
-    def __init__(self, community, circuit, info_hash):
+    def __init__(self, community, circuit, info_hash, target):
         super().__init__(community.request_cache, "peers-request")
+        self.community = community
         self.circuit = circuit
         self.info_hash = info_hash
+        self.target = target
         self.future = Future()
         self.register_future(self.future, RuntimeError("Peers request timeout"))
 
+    def on_timeout(self):
+        swarm = self.community.swarms.get(self.info_hash)
+        if swarm and self.target:
+            # This introduction point did not respond in time, so drop it.
+            swarm.remove_intro_point(self.target)
+
 
 class E2ERequestCache(RandomNumberCache):
 
     def __init__(self, community, info_hash, hop, intro_point):
         super().__init__(community.request_cache, "e2e-request")
-        self.community = community
         self.info_hash = info_hash
         self.hop = hop
         self.intro_point = intro_point
 
-    def on_timeout(self):
-        swarm = self.community.swarms.get(self.info_hash)
-        if swarm:
-            # This introduction point did not respond in time, so drop it.
-            swarm.remove_intro_point(self.intro_point)
-
 
 class LinkRequestCache(RandomNumberCache):
 
