@@ -4,6 +4,7 @@ The tunnel community.
 Author(s): Egbert Bouman
 """
 import os
+import random
 from asyncio import iscoroutine, sleep
 from binascii import unhexlify
 from collections import defaultdict
@@ -69,13 +70,12 @@ class TunnelSettings(object):
         self.next_hop_timeout = 10
 
         self.swarm_lookup_interval = 30
-        self.swarm_connection_limit = 5
+        self.swarm_connection_limit = 15
 
         # We have a small delay when removing circuits/relays/exit nodes. This is to allow some post-mortem data
         # to flow over the circuit (i.e. bandwidth payouts to intermediate nodes in a circuit).
         self.remove_tunnel_delay = 5
 
-        self.num_ip_circuits = 3
         self.peer_flags = {PEER_FLAG_RELAY, PEER_FLAG_SPEED_TEST}
 
         # Maximum number of relay_early cells that are allowed to pass a relay.
@@ -721,7 +721,7 @@ class TunnelCommunity(Community):
             self.remove_exit_socket(request.from_circuit_id)
 
             self.send_cell(relay.peer,
-                           ExtendedPayload(relay.circuit_id, payload.identifier,
+                           ExtendedPayload(relay.circuit_id, request.extend_identifier,
                                            payload.key, payload.auth, payload.candidate_list_enc))
         elif self.request_cache.has("retry", payload.identifier):
             circuit = self.circuits[circuit_id]
@@ -778,8 +778,7 @@ class TunnelCommunity(Community):
         self.request_cache.add(cache)
 
         self.send_cell(extend_candidate,
-                       CreatePayload(to_circuit_id, payload.identifier,
-                                     self.my_peer.public_key.key_to_bin(), payload.key))
+                       CreatePayload(to_circuit_id, cache.number, self.my_peer.public_key.key_to_bin(), payload.key))
 
     @unpack_cell(ExtendedPayload)
     def on_extended(self, source_address, payload, _):
@@ -814,7 +813,8 @@ class TunnelCommunity(Community):
         if circuit and origin and sock_addr == circuit.peer.address:
             circuit.beat_heart()
 
-            if DataChecker.could_be_ipv8(data):
+            e2e_data = circuit.ctype in [CIRCUIT_TYPE_RP_DOWNLOADER, CIRCUIT_TYPE_RP_SEEDER]
+            if DataChecker.could_be_ipv8(data) and not e2e_data:
                 if self._prefix == data[:22]:
                     self.logger.debug("Incoming packet meant for us")
                     self.on_packet_from_circuit(origin, data, circuit_id)
@@ -931,12 +931,13 @@ class TunnelCommunity(Community):
         payload, _ = self.serializer.unpack_serializable(TestRequestPayload, data, offset=23)
         exit_socket = self.exit_sockets.get(circuit_id)
         circuit = self.circuits.get(circuit_id)
-        if not exit_socket and not (circuit and circuit.ctype == CIRCUIT_TYPE_RP_SEEDER):
+        if not exit_socket and not (circuit and circuit.ctype in [CIRCUIT_TYPE_RP_SEEDER, CIRCUIT_TYPE_RP_DOWNLOADER]):
             self.logger.error("Dropping test-request with unknown circuit_id")
             return
 
         self.logger.debug("Got test-request (%d) from %s, replying with response", circuit_id, source_address)
-        (exit_socket or circuit).beat_heart()
+        if exit_socket:
+            exit_socket.beat_heart()
         self.send_cell(source_address,
                        TestResponsePayload(circuit_id, payload.identifier, os.urandom(payload.response_size)))
 
